@@ -209,78 +209,6 @@ extern const char* System_dirname(const char* str)
   return res;
 }
 
-#if defined(OPENMODELICA_BOOTSTRAPPING_STAGE_1)
-extern const char* System_getRTLibs()
-{
-  return "DUMMY RT LIBS";
-}
-
-extern const char* System_getRTLibsSim()
-{
-  return "DUMMY RT LIBS";
-}
-
-extern const char* System_getRTLibsFMU()
-{
-  return "DUMMY RT LIBS";
-}
-
-extern const char* System_getExeExt()
-{
-  return ".exe";
-}
-
-extern const char* System_getDllExt()
-{
-  return CONFIG_DLL_EXT;
-}
-
-extern const char* System_getMakeCommand()
-{
-  return "make";
-}
-
-extern const char* System_os()
-{
-  return "Windows_NT";
-}
-
-extern const char* System_configureCommandLine()
-{
-  return "Dummy configure";
-}
-
-extern const char* System_platform()
-{
-  return "Dummy platform";
-}
-
-extern const char* System_pathDelimiter()
-{
-  return "/";
-}
-
-extern const char* System_groupDelimiter()
-{
-  return ";";
-}
-
-extern const char* System_getCorbaLibs()
-{
-  return "Dummy CORBA libs";
-}
-
-extern void* System_getRuntimeLibs()
-{
-  return "Dummy system libs";
-}
-
-const char* System_getTriple()
-{
-  return "DEFAULT_TRIPLE";
-}
-#endif
-
 extern int System_strncmp(const char *str1, const char *str2, int len)
 {
   int res= strncmp(str1,str2,len);
