@@ -51,6 +51,9 @@ extern "C" {
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#if defined(__MINGW32__)
+#define _POSIX_THREAD_SAFE_FUNCTIONS 200112L /* for ctime_r in time.h */
+#endif
 #include <time.h>
 #include <math.h>
 
@@ -1786,11 +1789,9 @@ extern char* SystemImpl__unquoteIdentifier(char* str)
     return System_sanitizeQuotedIdentifier(str);
   }
 
-#if !defined(OPENMODELICA_BOOTSTRAPPING_STAGE_1)
   if (strstr(str, "$")) {
     return System_sanitizeQuotedIdentifier(str);
   }
-#endif
 
   return str;
 }
@@ -1912,18 +1913,14 @@ static int SystemImpl__uriToClassAndPath(const char *uri, const char **scheme, c
   return 1;
 }
 
-#ifdef NO_LAPACK
-int SystemImpl__dgesv(void *lA, void *lB, void **res)
-{
-  MMC_THROW();
-}
-#else
 /* adrpo 2011-06-23
  * extern definition to dgesv_ from -llapack
  * as we do not link with -lsim and the one
  * in matrix.h got renamed to _omc_dgesv_ to
  * avoid name clashes!
  */
+#ifdef HAVE_LAPACK
+
 extern int dgesv_(integer *n, integer *nrhs, doublereal *a, integer *lda, integer *ipiv, doublereal *b, integer *ldb, integer *info);
 
 int SystemImpl__dgesv(void *lA, void *lB, void **res)
@@ -1965,6 +1962,14 @@ int SystemImpl__dgesv(void *lA, void *lB, void **res)
   *res = tmp;
   return info;
 }
+
+#else
+int SystemImpl__dgesv(void *lA, void *lB, void **res)
+{
+  c_add_message(NULL, -1, ErrorType_runtime, ErrorLevel_error,
+                "A LAPACK routine is called but OMC is not compiled with LAPACK support", NULL, 0);
+  MMC_THROW();
+}
 #endif
 
 #ifdef NO_LPLIB
@@ -2031,13 +2036,17 @@ typedef struct {
   int fileIsDir;
 } modelicaPathEntry;
 
-void splitVersion(const char *version, long *versionNum, char **versionExtra)
+int splitVersion(const char *version, long *versionNum, char **versionExtra)
 {
   const char *buf = version;
   char *next;
   long l;
   int cont,i=0,len;
   memset(versionNum,0,sizeof(long)*MODELICAPATH_LEVELS);
+  if (!isdigit(version[0])) {
+    *versionExtra = omc_alloc_interface.malloc_strdup(buf);
+    return 0;
+  }
   do {
     /* fprintf(stderr, "look versionNum %s\n", buf); */
     l = strtol(buf,&next,10);
@@ -2056,6 +2065,7 @@ void splitVersion(const char *version, long *versionNum, char **versionExtra)
   if (len >= 2 && 0==strcmp("mo", *versionExtra+len-2)) {
     (*versionExtra)[len-2] = '\0';
   }
+  return 1;
 }
 
 static int regularFileExistsInDirectory(const char *dir1, const char *dir2, const char *file)
@@ -2171,12 +2181,13 @@ static int modelicaPathEntryVersionGreater(long *ver1, long *ver2, int numToTest
 
 static int getLoadModelPathFromSingleTarget(const char *searchTarget, modelicaPathEntry *entries, int numEntries, int exactVersion, const char **outDir, char **outName, int *isDir)
 {
-  int i, j, foundIndex = -1;
+  int i, j, foundIndex = -1, foundDigitVersion;
   long version[MODELICAPATH_LEVELS] = {0}, foundVersion[MODELICAPATH_LEVELS] = {0};
   char *versionExtra;
-  splitVersion(searchTarget,version,&versionExtra);
+  /* fprintf(stderr, "searchTarget %s\n", searchTarget); */
+  foundDigitVersion = splitVersion(searchTarget,version,&versionExtra);
   /* fprintf(stderr, "expected %ld.%ld.%ld.%ld %s ; exact=%d\n", version[0], version[1], version[2], version[3], versionExtra, exactVersion); */
-  if (version > 0 && !*versionExtra) {
+  if (foundDigitVersion && !*versionExtra) {
     /* Makes us load 3.2.1 if 3.2.0.0 is not available.
      * Note that all 4 levels are present and 3.2 is equivalent to 3.2.0.0
      * Search one additional level for each time we fail.
@@ -2203,17 +2214,15 @@ static int getLoadModelPathFromSingleTarget(const char *searchTarget, modelicaPa
       }
     }
   }
-  if (*versionExtra) {
-    /* fprintf(stderr, "Look for version %lx versionExtra: %s\n", version, versionExtra); */
-    for (i=0; i<numEntries; i++) {
-      /* fprintf(stderr, "entry %s/%s\n", entries[i].dir, entries[i].file);
-      fprintf(stderr, "is %ld.%ld.%ld.%ld %s\n", entries[i].version[0], entries[i].version[1], entries[i].version[2], entries[i].version[3], entries[i].versionExtra); */
-      if (modelicaPathEntryVersionEqual(entries[i].version,version,MODELICAPATH_LEVELS) && 0==strncmp(entries[i].versionExtra,versionExtra,strlen(versionExtra))) {
-        *outDir = entries[i].dir;
-        *outName = entries[i].file;
-        *isDir = entries[i].fileIsDir;
-        return 0;
-      }
+  /* fprintf(stderr, "Look for version %lx versionExtra: %s\n", version, versionExtra); */
+  for (i=0; i<numEntries; i++) {
+    /* fprintf(stderr, "entry %s/%s\n", entries[i].dir, entries[i].file);
+    fprintf(stderr, "is %ld.%ld.%ld.%ld %s\n", entries[i].version[0], entries[i].version[1], entries[i].version[2], entries[i].version[3], entries[i].versionExtra); */
+    if (modelicaPathEntryVersionEqual(entries[i].version,version,MODELICAPATH_LEVELS) && 0==strncmp(entries[i].versionExtra,versionExtra,strlen(versionExtra))) {
+      *outDir = entries[i].dir;
+      *outName = entries[i].file;
+      *isDir = entries[i].fileIsDir;
+      return 0;
     }
   }
   return 1;
@@ -2368,14 +2377,6 @@ extern int SystemImpl_tmpTickMaximum(threadData_t *threadData, int index)
   return data->tmp_tick_max_no[index];
 }
 
-#if defined(OPENMODELICA_BOOTSTRAPPING_STAGE_1)
-extern int SystemImpl_tmpTick(threadData_t *threadData)
-{
-  int res = SystemImpl_tmpTickIndex(threadData,0);
-  return res;
-}
-#endif
-
 extern void SystemImpl_tmpTickReset(threadData_t *threadData, int start)
 {
   SystemImpl_tmpTickResetIndex(threadData,start,0);
