@@ -16,29 +16,18 @@
 #include<Core/Math/ILapack.h>
 #include <Solver/Kinsol/FactoryExport.h>
 
-#include <nvector/nvector_serial.h>
 #include <kinsol/kinsol.h>
-
-#include <kinsol/kinsol_spgmr.h>
-#include <kinsol/kinsol_dense.h>
-
-#include <kinsol/kinsol_spbcgs.h>
-#include <kinsol/kinsol_sptfqmr.h>
-/*will be used with new sundials version
-#include <kinsol/kinsol_klu.h>
-*/
-#include <kinsol/kinsol_direct.h>
-#include <sundials/sundials_dense.h>
-#include <kinsol/kinsol_impl.h>
-
+#include <nvector/nvector_serial.h>
+#include <sunlinsol/sunlinsol_dense.h>      /* Default dense linear solver */
+/* Will be used with new sundials version */
+//#include <sunlinsol/sunlinsol_klu.h>      /* Linear solver KLU */
+#include <sunlinsol/sunlinsol_spgmr.h>      /* Scaled, Preconditioned, Generalized Minimum Residual iterative linear solver */
+#include <sunlinsol/sunlinsol_spbcgs.h>     /* Scaled, Preconditioned, Bi-Conjugate Gradient, Stabilized iterative linear solver */
 
 #include <Core/Utils/extension/logger.hpp>
 #include <Solver/Kinsol/KinsolLapack.h>
 #include <Solver/Kinsol/Kinsol.h>
 #include <Solver/Kinsol/KinsolSettings.h>
-#if defined(__TRICORE__)
-#include <include/kinsol/kinsol.h>
-#endif
 
 //#include <Core/Utils/numeric/bindings/lapack/driver/gesv.hpp>
 #include <Core/Utils/numeric/bindings/ublas.hpp>
@@ -129,6 +118,9 @@ Kinsol::Kinsol(INonLinSolverSettings* settings, shared_ptr<INonLinearAlgLoop> al
       , _Kin_y0(NULL)
       , _Kin_yScale(NULL)
       , _Kin_fScale(NULL)
+      , _Kin_ySolver(NULL)
+      , _Kin_linSol(NULL)
+      , _Kin_J(NULL)
       , _kinMem(NULL)
       /*
       , _kluSymbolic             (NULL)
@@ -182,6 +174,12 @@ Kinsol::~Kinsol()
         N_VDestroy_Serial(_Kin_yScale);
     if (_Kin_fScale)
         N_VDestroy_Serial(_Kin_fScale);
+    if (_Kin_ySolver)
+        N_VDestroy_Serial(_Kin_ySolver);
+    if (_Kin_J)
+        SUNMatDestroy(_Kin_J);
+    if (_Kin_linSol)
+        SUNLinSolFree(_Kin_linSol);
     if (_kinMem)
         KINFree(&_kinMem);
 
@@ -274,6 +272,12 @@ void Kinsol::initialize()
         N_VDestroy_Serial(_Kin_yScale);
     if (_Kin_fScale)
         N_VDestroy_Serial(_Kin_fScale);
+    if (_Kin_ySolver)
+        N_VDestroy(_Kin_ySolver);
+    if (_Kin_J)
+        SUNMatDestroy(_Kin_J);
+    if (_Kin_linSol)
+        SUNLinSolFree(_Kin_linSol);
     if (_kinMem)
         KINFree(&_kinMem);
 
@@ -281,6 +285,7 @@ void Kinsol::initialize()
     _Kin_y0 = N_VMake_Serial(_dimSys, _y0);
     _Kin_yScale = N_VMake_Serial(_dimSys, _yScale);
     _Kin_fScale = N_VMake_Serial(_dimSys, _fScale);
+    _Kin_ySolver = N_VNew_Serial(_dimSys);
     _kinMem = KINCreate();
 
     /*
@@ -324,7 +329,18 @@ void Kinsol::initialize()
     if (check_flag(&idid, (char *)"KINSetUserData", 1))
         throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::initialize()");
 
-    KINDense(_kinMem, _dimSys);
+    // Initialize dense linear solver
+    _Kin_J = SUNDenseMatrix(_dimSys, _dimSys);
+    _Kin_linSol = SUNLinSol_Dense(_Kin_ySolver, _Kin_J);
+    if (_Kin_linSol == NULL)
+    {
+        fprintf(stderr,
+                "\nSUNDIALS_ERROR: SUNLinSol_Dense() failed - returned NULL pointer\n\n");
+        throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::solve()");
+    }
+    idid = KINSetLinearSolver(_kinMem, _Kin_linSol, _Kin_J);
+    if (check_flag(&idid, (char *)"KINSetLinearSolver", 1))
+        throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::initialize()");
 
     /*will be used with new sundials version
     if(_algLoop->isLinearTearing())
@@ -416,7 +432,22 @@ void Kinsol::solve()
     ////////////////////////////
     if (_usedCompletePivoting || _usedIterativeSolver)
     {
-        KINDense(_kinMem, _dimSys);
+        // Last call was with comlpete pivoting or iterative solver
+        // Reinitialize dense solve again
+        idid = SUNLinSolFree(_Kin_linSol);
+        if (check_flag(&idid, (char *)"SUNLinSolFree", 1))
+            throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::solve()");
+        _Kin_linSol = SUNLinSol_Dense(_Kin_ySolver, _Kin_J);
+        if (_Kin_linSol == NULL)
+        {
+            fprintf(stderr,
+                    "\nSUNDIALS_ERROR: SUNLinSol_Dense() failed - returned NULL pointer\n\n");
+            throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::solve()");
+        }
+        idid = KINSetLinearSolver(_kinMem, _Kin_linSol, _Kin_J);
+        if (check_flag(&idid, (char *)"KINSetUserData", 1))
+            throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::initialize()");
+
         _usedCompletePivoting = false;
         _usedIterativeSolver = false;
     }
@@ -432,25 +463,24 @@ void Kinsol::solve()
 
         return;
     }
-    else // Try Scaling
+
+    // Try Dense with scaling
+    ////////////////////////////
+    _iterationStatus = CONTINUE;
+    _algLoop->setReal(_y0);
+    _algLoop->evaluate();
+    _algLoop->getRHS(_fScale);
+    for (int i = 0; i < _dimSys; i++)
     {
-        _iterationStatus = CONTINUE;
-        _algLoop->setReal(_y0);
-        _algLoop->evaluate();
-        _algLoop->getRHS(_fScale);
-        for (int i = 0; i < _dimSys; i++)
-        {
-            if (abs(_fScale[i]) > 1.0)
-                _fScale[i] = abs(1 / _fScale[i]);
-            else
-                _fScale[i] = 1;
-        }
-
-        _iterationStatus = CONTINUE;
-
-        solveNLS();
+        if (abs(_fScale[i]) > 1.0)
+            _fScale[i] = abs(1 / _fScale[i]);
+        else
+            _fScale[i] = 1;
     }
 
+    _iterationStatus = CONTINUE;
+
+    solveNLS();
     if (_iterationStatus == DONE)
     {
         _algLoop->setReal(_y);
@@ -496,14 +526,28 @@ void Kinsol::solve()
     //if(_iterationStatus == DONE)
     //    return;
 
-    //Try iterative Solvers
+    // Try SPGMR solver
+    // Scaled, Preconditioned, Generalized Minimum Residual iterative linear solver
     /////////////////////////////////
     _usedIterativeSolver = true;
 
     for (int i = 0; i < _dimSys; i++) // Reset Scaling
         _fScale[i] = 1.0;
 
-    KINSpgmr(_kinMem, _dimSys);
+    /* Free linear solver and initialize linear solver */
+    idid = SUNLinSolFree(_Kin_linSol);
+    if (check_flag(&idid, (char *)"SUNLinSolFree", 1))
+        throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::solve()");
+    _Kin_linSol = SUNLinSol_SPGMR(_Kin_ySolver, PREC_NONE, _dimSys);
+    if (_Kin_linSol == NULL)
+    {
+        fprintf(stderr,
+                "\nSUNDIALS_ERROR: SUNLinSol_SPGMR() failed - returned NULL pointer\n\n");
+        throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::solve()");
+    }
+    idid = KINSetLinearSolver(_kinMem, _Kin_linSol, NULL);
+    if (check_flag(&idid, (char *)"KINSetLinearSolver", 1))
+        throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::solve()");
 
     _iterationStatus = CONTINUE;
     solveNLS();
@@ -515,22 +559,23 @@ void Kinsol::solve()
 
         return;
     }
-    else // Try Scaling
+
+    // Try SPGMR solver with scaling
+    /////////////////////////////////
+    _iterationStatus = CONTINUE;
+    _algLoop->setReal(_y0);
+    _algLoop->evaluate();
+    _algLoop->getRHS(_fScale);
+    for (int i = 0; i < _dimSys; i++)
     {
-        _iterationStatus = CONTINUE;
-        _algLoop->setReal(_y0);
-        _algLoop->evaluate();
-        _algLoop->getRHS(_fScale);
-        for (int i = 0; i < _dimSys; i++)
-        {
-            if (abs(_fScale[i]) > 1.0)
-                _fScale[i] = abs(1 / _fScale[i]);
-            else
-                _fScale[i] = 1;
-        }
-        _iterationStatus = CONTINUE;
-        solveNLS();
+        if (abs(_fScale[i]) > 1.0)
+            _fScale[i] = abs(1 / _fScale[i]);
+        else
+            _fScale[i] = 1;
     }
+    _iterationStatus = CONTINUE;
+    solveNLS();
+
     if (_iterationStatus == DONE)
     {
         _algLoop->setReal(_y);
@@ -538,10 +583,27 @@ void Kinsol::solve()
         return;
     }
 
+    // Try SPBCG solver
+    // Scaled, Preconditioned, Generalized Minimum Residual iterative linear solver
+    /////////////////////////////////
     for (int i = 0; i < _dimSys; i++) // Reset Scaling
         _fScale[i] = 1.0;
 
-    KINSpbcg(_kinMem, _dimSys);
+    /* Free linear solver and initialize linear solver */
+    idid = SUNLinSolFree(_Kin_linSol);
+    if (check_flag(&idid, (char *)"SUNLinSolFree", 1))
+        throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::solve()");
+    _Kin_linSol = SUNLinSol_SPBCGS(_Kin_ySolver, PREC_NONE, _dimSys);
+    if (_Kin_linSol == NULL)
+    {
+        fprintf(stderr,
+                "\nSUNDIALS_ERROR: SUNLinSol_SPGMR() failed - returned NULL pointer\n\n");
+        throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::solve()");
+    }
+    idid = KINSetLinearSolver(_kinMem, _Kin_linSol, _Kin_J);
+    if (check_flag(&idid, (char *)"KINSetLinearSolver", 1))
+        throw ModelicaSimulationError(ALGLOOP_SOLVER, "Kinsol::solve()");
+
     _iterationStatus = CONTINUE;
     solveNLS();
     if (_iterationStatus == DONE)
@@ -550,21 +612,22 @@ void Kinsol::solve()
         _algLoop->evaluate();
         return;
     }
-    else // Try Scaling
+
+    // Try SPBCG solver with scaling
+    /////////////////////////////////
+    _iterationStatus = CONTINUE;
+    _algLoop->setReal(_y0);
+    _algLoop->evaluate();
+    _algLoop->getRHS(_fScale);
+    for (int i = 0; i < _dimSys; i++)
     {
-        _iterationStatus = CONTINUE;
-        _algLoop->setReal(_y0);
-        _algLoop->evaluate();
-        _algLoop->getRHS(_fScale);
-        for (int i = 0; i < _dimSys; i++)
-        {
-            if (abs(_fScale[i]) > 1.0)
-                _fScale[i] = abs(1 / _fScale[i]);
-            else
-                _fScale[i] = 1;
-        }
-        solveNLS();
+        if (abs(_fScale[i]) > 1.0)
+            _fScale[i] = abs(1 / _fScale[i]);
+        else
+            _fScale[i] = 1;
     }
+    solveNLS();
+
     if (_iterationStatus == DONE)
     {
         _algLoop->setReal(_y);
@@ -579,6 +642,8 @@ void Kinsol::solve()
         return;
     }
 
+    // Give up
+    /////////////////////////////////
     if (_iterationStatus == SOLVERERROR && !_eventRetry)
     {
         if (_kinsolSettings->getContinueOnError())
@@ -592,7 +657,6 @@ void Kinsol::solve()
             }
         }
         else
-
             throw ModelicaSimulationError(ALGLOOP_SOLVER, "Nonlinear solver failed!");
     }
 }
@@ -712,7 +776,7 @@ int Kinsol::check_flag(void* flagvalue, char* funcname, int opt)
         return (1);
     }
 
-        /* Check if flag < 0 */
+    /* Check if flag < 0 */
     else if (opt == 1)
     {
         errflag = (int *)flagvalue;
@@ -725,7 +789,7 @@ int Kinsol::check_flag(void* flagvalue, char* funcname, int opt)
         }
     }
 
-        /* Check if function returned NULL pointer - no memory allocated */
+    /* Check if function returned NULL pointer - no memory allocated */
     else if (opt == 2 && flagvalue == NULL)
     {
         fprintf(stderr,
