@@ -58,9 +58,9 @@
 
 int maxEventIterations = 20;
 double linearSparseSolverMaxDensity = 0.2;
-int linearSparseSolverMinSize = 201;
+int linearSparseSolverMinSize = DEFAULT_FLAG_LSS_MIN_SIZE;
 double nonlinearSparseSolverMaxDensity = 0.2;
-int nonlinearSparseSolverMinSize = 10001;
+int nonlinearSparseSolverMinSize = DEFAULT_FLAG_NLS_MIN_SIZE;
 double maxStepFactor = 1e12;
 double newtonXTol = 1e-12;
 double newtonFTol = 1e-12;
@@ -370,31 +370,42 @@ void printParameters(DATA *data, int stream)
   TRACE_POP
 }
 
-/*! \fn printSparseStructure
+/**
+ * @brief Prints sparse structure.
  *
- *  prints sparse structure of jacobian A
- *
- *  \param [in]  [sparsePattern]
- *  \param [in]  [sizeRow]
- *  \param [in]  [sizeCol]
- *  \param [in]  [stream]
+ * Use to print e.g. sparse Jacobian matrix.
+ * Only prints if stream is active and sparse pattern is non NULL and of size > 0.
  *
+ * @param [in]  sparsePattern   Matrix to print.
+ * @param [in]  sizeRows        Number of rows of matrix.
+ * @param [in]  sizeCols        Number of columns of matrix.
+ * @param [in]  stream          Steam to print to.
+ * @param [in]  name            Name of matrix.
  */
 void printSparseStructure(SPARSE_PATTERN *sparsePattern, int sizeRows, int sizeCols, int stream, const char* name)
 {
+  /* Variables */
   unsigned int row, col, i, j;
-  /* Will crash with a static size array */
-  char *buffer = NULL;
+  char *buffer;
 
   if (!ACTIVE_STREAM(stream))
+  {
     return;
+  }
+
+  /* Catch empty sparsePattern */
+  if (sparsePattern == NULL || sizeRows <= 0 || sizeCols <= 0)
+  {
+    infoStreamPrint(stream, 0, "No sparse strucutre available for \"%s\".", name);
+    return;
+  }
 
   buffer = (char*)omc_alloc_interface.malloc(sizeof(char)* 2*sizeCols + 4);
 
-  infoStreamPrint(stream, 1, "sparse structure of %s [size: %ux%u]", name, sizeRows, sizeCols);
+  infoStreamPrint(stream, 1, "Sparse structure of %s [size: %ux%u]", name, sizeRows, sizeCols);
   infoStreamPrint(stream, 0, "%u nonzero elements", sparsePattern->numberOfNoneZeros);
 
-  infoStreamPrint(stream, 1, "transposed sparse structure (rows: states)");
+  infoStreamPrint(stream, 1, "Transposed sparse structure (rows: states)");
   i=0;
   for(row=0; row < sizeRows; row++)
   {
@@ -1397,8 +1408,8 @@ modelica_integer _event_mod_integer(modelica_integer x1, modelica_integer x2, mo
     data->simulationInfo->mathEventsValuePre[index] = (modelica_real)x1;
     data->simulationInfo->mathEventsValuePre[index+1] = (modelica_real)x2;
   }
-
-  return x1 - (x1 / x2) * x2;
+  modelica_integer tmp = x1 % x2;
+  return ((x2 > 0 && tmp < 0) || (x2 < 0 && tmp > 0)) ? (tmp + x2) : tmp;
 }
 
 /*! \fn _event_mod_real
