@@ -42,12 +42,18 @@
 #include "util/rtclock.h"
 #include "util/rational.h"
 #include "util/list.h"
+#include "util/simulation_options.h"
 
 #define omc_dummyVarInfo {-1,-1,"","",omc_dummyFileInfo}
 #define omc_dummyEquationInfo {-1,0,0,-1,NULL}
 #define omc_dummyFunctionInfo {-1,"",omc_dummyFileInfo}
 #define omc_dummyRealAttribute {NULL,NULL,-DBL_MAX,DBL_MAX,0,0,1.0,0.0}
 
+#define OMC_LINEARIZE_DUMP_LANGUAGE_MODELICA 0
+#define OMC_LINEARIZE_DUMP_LANGUAGE_MATLAB 1
+#define OMC_LINEARIZE_DUMP_LANGUAGE_JULIA 2
+#define OMC_LINEARIZE_DUMP_LANGUAGE_PYTHON 3
+
 #if defined(_MSC_VER)
 #define set_struct(TYPE, x, info) { const TYPE tmp = info; x = tmp; }
 #else
@@ -120,6 +126,8 @@ typedef enum {ERROR_AT_TIME,NO_PROGRESS_START_POINT,NO_PROGRESS_FACTOR,IMPROPER_
  * sizeofIndex contain number of elements in index
  * colorsCols contain color of colored columns
  *
+ * Use freeSparsePattern(SPARSE_PATTERM *spp) for "destruction" (see util/jacobian_util.c/h).
+ *
  */
 typedef struct SPARSE_PATTERN
 {
@@ -142,16 +150,18 @@ typedef struct SPARSE_PATTERN
  * resultVars contain result of one column to the corresponding jacobian
  * jacobian contains dense jacobian elements
  *
+ * Use freeAnalyticJacobian(ANALYTIC_JACOBIAN *jac) for "destruction" (see util/jacobian_util.c/h).
  */
 typedef struct ANALYTIC_JACOBIAN
 {
   unsigned int sizeCols;
   unsigned int sizeRows;
   unsigned int sizeTmpVars;
-  SPARSE_PATTERN sparsePattern;
+  SPARSE_PATTERN* sparsePattern;
   modelica_real* seedVars;
   modelica_real* tmpVars;
   modelica_real* resultVars;
+  int (*constantEqns)(void* data, threadData_t *threadData, void* thisJacobian, void* parentJacobian);
 }ANALYTIC_JACOBIAN;
 
 /* EXTERNAL_INPUT
@@ -272,7 +282,7 @@ typedef struct NONLINEAR_SYSTEM_DATA
   int (*initialAnalyticalJacobian)(void*, threadData_t*, ANALYTIC_JACOBIAN*);
   modelica_integer jacobianIndex;
 
-  SPARSE_PATTERN sparsePattern;        /* sparse pattern if no jacobian is available */
+  SPARSE_PATTERN *sparsePattern;        /* sparse pattern if no jacobian is available */
   modelica_boolean isPatternAvailable;
 
   void (*residualFunc)(void**, const double*, double*, const int*);
@@ -309,6 +319,28 @@ typedef struct NONLINEAR_SYSTEM_DATA
 typedef void* NONLINEAR_SYSTEM_DATA;
 #endif
 
+typedef struct LINEAR_SYSTEM_THREAD_DATA
+{
+  void *solverData[2];                  /* [1] is the totalPivot solver
+                                           [0] holds other solvers
+                                           both are used for the default solver */
+  modelica_real *x;                     /* solution vector x */
+  modelica_real *A;                     /* matrix A */
+  modelica_real *b;                     /* vector b */
+
+  modelica_real residualError;          /* not used yet*/
+
+  ANALYTIC_JACOBIAN* parentJacobian;    /* if != NULL then it's the parent jacobian matrix */
+  ANALYTIC_JACOBIAN* jacobian;          /* jacobian */
+
+  /* Statistics for each thread */
+  unsigned long numberOfCall;           /* number of solving calls of this system */
+  unsigned long numberOfJEval;          /* number of jacobian evaluations of this system */
+  double totalTime;                     /* save the totalTime */
+  rtclock_t totalTimeClock;             /* time clock for the totalTime  */
+  double jacobianTime;                  /* save the time to calculate jacobians */
+}LINEAR_SYSTEM_THREAD_DATA;
+
 #if !defined(OMC_NUM_LINEAR_SYSTEMS) || OMC_NUM_LINEAR_SYSTEMS>0
 typedef struct LINEAR_SYSTEM_DATA
 {
@@ -322,7 +354,6 @@ typedef struct LINEAR_SYSTEM_DATA
 
   int (*analyticalJacobianColumn)(void*, threadData_t*, ANALYTIC_JACOBIAN*, ANALYTIC_JACOBIAN* parentJacobian);
   int (*initialAnalyticalJacobian)(void*, threadData_t*, ANALYTIC_JACOBIAN*);
-  modelica_integer jacobianIndex;
 
   void (*residualFunc)(void**, const double*, double*, const int*);
   void (*initializeStaticLSData)(void*, threadData_t *threadData, void*);
@@ -337,19 +368,19 @@ typedef struct LINEAR_SYSTEM_DATA
   modelica_integer nnz;                 /* number of nonzero entries */
   modelica_integer size;
   modelica_integer equationIndex;       /* index for EQUATION_INFO */
+  modelica_integer jacobianIndex;
 
-  void *solverData[2]; /* [1] is the totalPivot solver; [0] holds other solvers ; both are used for the default solver */
-  modelica_real *x;                     /* solution vector x */
-  modelica_real *A;                     /* matrix A */
-  modelica_real *b;                     /* vector b */
+  modelica_integer method;              /* 0: No Jacobain created for linear system
+                                         * 1: Symbolic Jacobian available for linear system */
+  modelica_boolean useSparseSolver;     /* 1: use sparse solver, - else any solver */
 
-  modelica_integer method;              /* not used yet*/
-  modelica_real residualError;          /* not used yet*/
+  LINEAR_SYSTEM_THREAD_DATA* parDynamicData; /* Array of length numMaxThreads for internal write data */
+
+  // ToDo: Gather information from all threads if in parallel region
   modelica_boolean solved;              /* 1: solved in current step - else not */
   modelica_boolean failed;              /* 1: failed while last try with lapack - else not */
-  modelica_boolean useSparseSolver;     /* 1: use sparse solver, - else any solver */
-  ANALYTIC_JACOBIAN* parentJacobian; 	/* if != NULL then it's the parent jacobian matrix */
 
+  // ToDo: Gather information from all threads if in parallel region
   /* statistics */
   unsigned long numberOfCall;           /* number of solving calls of this system */
   unsigned long numberOfJEval;          /* number of jacobian evaluations of this system */
@@ -377,7 +408,7 @@ typedef struct MIXED_SYSTEM_DATA
   modelica_boolean** iterationPreVarsPtr;
   void *solverData;
 
-  modelica_integer method;          /* not used yet*/
+  modelica_integer method;          /* not used yet */
   modelica_boolean solved;          /* 1: solved in current step - else not */
 }MIXED_SYSTEM_DATA;
 #else
@@ -504,6 +535,9 @@ typedef struct MODEL_DATA
   const char* modelGUID;
   const char* initXMLData;
   char* resourcesDir;
+  modelica_boolean runTestsuite; /* true if this model was generated during testing */
+
+  int linearizationDumpLanguage;       /* default is 0-modelica, options: 1-matlab, 2-julia, 3-pythong */
 
   long nSamples;                       /* number of different sample-calls */
   SAMPLE_INFO* samplesInfo;            /* array containing each sample-call */
@@ -548,6 +582,8 @@ typedef struct MODEL_DATA
 
   long nSensitivityVars;
   long nSensitivityParamVars;
+  long nSetcVars;
+  long ndataReconVars;
 }MODEL_DATA;
 
 typedef struct CLOCK_DATA {
@@ -576,11 +612,15 @@ typedef struct SIMULATION_INFO
   int useStopTime;
   modelica_integer numSteps;
   modelica_real stepSize;
+  modelica_real minStepSize;           /* defines the minimal step size */
   modelica_real tolerance;
   const char *solverMethod;
   const char *outputFormat;
   const char *variableFilter;
 
+  double loggingTimeRecord[2];          /* Time interval in which logging is active. Only used if useLoggingTime=1 */
+  int useLoggingTime;                   /* 0 if logging is currently disabled, 1 if enabled */
+
   int lsMethod;                        /* linear solver */
   int lssMethod;                       /* linear sparse solver */
   int mixedMethod;                     /* mixed solver */
@@ -648,12 +688,15 @@ typedef struct SIMULATION_INFO
 
   modelica_real* inputVars;
   modelica_real* outputVars;
+  modelica_real* setcVars;
+  modelica_real* datainputVars;
+
   EXTERNAL_INPUT external_input;
 
   modelica_real* sensitivityMatrix;    /* used by integrator for sensitivity mode  */
   int* sensitivityParList;             /* used by integrator for sensitivity mode  */
 
-  ANALYTIC_JACOBIAN* analyticJacobians;
+  ANALYTIC_JACOBIAN* analyticJacobians;   // ToDo Only store informations for Jacobian used by integrator here
 
   NONLINEAR_SYSTEM_DATA* nonlinearSystemData;
   int currentNonlinearSystemIndex;
