@@ -33,6 +33,7 @@
 
 #include "../openmodelica.h"
 #include "base_array.h"
+#include "generic_array.h"
 #include "index_spec.h"
 #include "omc_msvc.h"
 #include <stdarg.h>
@@ -84,9 +85,6 @@ static inline void clone_boolean_array_spec(const boolean_array_t* src,
                                             boolean_array_t* dst)
 { clone_base_array_spec(src, dst); }
 
-/* Copy boolean data*/
-extern void copy_boolean_array_data(const boolean_array_t source, boolean_array_t* dest);
-
 /* Copy boolean data given memory ptr*/
 extern void copy_boolean_array_data_mem(const boolean_array_t source, modelica_boolean* dest);
 
@@ -158,10 +156,6 @@ extern void array_alloc_boolean_array(boolean_array_t* dest,int n,
 extern void array_scalar_boolean_array(boolean_array_t* dest,int n,...);
 extern void array_alloc_scalar_boolean_array(boolean_array_t* dest,int n,...);
 
-extern m_boolean* boolean_array_element_addr(const boolean_array_t* source,int ndims,...);
-extern m_boolean* boolean_array_element_addr1(const boolean_array_t* source,int ndims,int dim1);
-extern m_boolean* boolean_array_element_addr2(const boolean_array_t* source,int ndims,int dim1,int dim2);
-
 extern void cat_boolean_array(int k,boolean_array_t* dest, int n,
                        const boolean_array_t* first,...);
 extern void cat_alloc_boolean_array(int k,boolean_array_t* dest, int n,
