@@ -52,12 +52,14 @@ SystemDefaultImplementation::SystemDefaultImplementation(IGlobalSettings *global
   , _dimTimeEvent      (0)
   , _dimClock        (0)
   , _dimAE        (0)
-  , _time_event_counter  (NULL)
+  , _timeEventData  (NULL)
+  , _currTimeEvents (NULL)
   , _clockInterval  (NULL)
   , _clockShift     (NULL)
   , _clockTime      (NULL)
   , _clockCondition (NULL)
   , _clockStart     (NULL)
+  , _clockSubactive (NULL)
   , _outputStream(NULL)
   , _callType        (IContinuous::UNDEF_UPDATE)
   , _initial        (false)
@@ -69,6 +71,7 @@ SystemDefaultImplementation::SystemDefaultImplementation(IGlobalSettings *global
   , _conditions0(NULL)
   , _event_system(NULL)
   , _modelName(modelName)
+  , _freeVariablesLock(false)
 {
 }
 
@@ -90,12 +93,14 @@ SystemDefaultImplementation::SystemDefaultImplementation(SystemDefaultImplementa
   , _dimTimeEvent      (0)
   , _dimClock        (0)
   , _dimAE        (0)
-  , _time_event_counter  (NULL)
+  , _timeEventData  (NULL)
+  , _currTimeEvents (NULL)
   , _clockInterval  (NULL)
   , _clockShift     (NULL)
   , _clockTime      (NULL)
   , _clockCondition (NULL)
   , _clockStart     (NULL)
+  , _clockSubactive (NULL)
   , _outputStream(NULL)
   , _callType        (IContinuous::UNDEF_UPDATE)
   , _initial        (false)
@@ -107,6 +112,7 @@ SystemDefaultImplementation::SystemDefaultImplementation(SystemDefaultImplementa
   , _conditions0(NULL)
   , _event_system(NULL)
   , _modelName(instance.getModelName())
+  , _freeVariablesLock(false)
 {
 }
 
@@ -133,13 +139,15 @@ SystemDefaultImplementation::~SystemDefaultImplementation()
   */
   if(_conditions) delete [] _conditions ;
   if(_time_conditions) delete [] _time_conditions ;
-  if(_time_event_counter) delete [] _time_event_counter;
+  if(_timeEventData) delete [] _timeEventData;
+  if(_currTimeEvents) delete [] _currTimeEvents;
   if(_conditions0) delete [] _conditions0;
   if(_clockInterval) delete [] _clockInterval;
   if(_clockShift) delete [] _clockShift;
   if(_clockTime) delete [] _clockTime;
   if(_clockCondition) delete [] _clockCondition;
   if(_clockStart) delete [] _clockStart;
+  if(_clockSubactive) delete [] _clockSubactive;
   if(__daeResidual) delete [] __daeResidual;
 }
 
@@ -191,6 +199,11 @@ int SystemDefaultImplementation::getDimClock() const
   return _dimClock;
 }
 
+void SystemDefaultImplementation::setIntervalInTimEventData(int clockIdx, double interval)
+{
+    _timeEventData[_dimTimeEvent-_dimClock+clockIdx].second = interval;
+}
+
 /// Provide number (dimension) of right hand sides (equations and/or residuals) according to the index
 int SystemDefaultImplementation::getDimRHS() const
 {
@@ -227,19 +240,13 @@ void SystemDefaultImplementation::initialize()
     _conditions0= new bool[_dimZeroFunc];
 
     memset(_conditions,false,(_dimZeroFunc)*sizeof(bool));
-	_event_system = dynamic_cast<IEvent*>(this);
+  _event_system = dynamic_cast<IEvent*>(this);
   }
   if(_dimTimeEvent > 0)
   {
     if(_time_conditions) delete [] _time_conditions ;
-    if(_time_event_counter) delete [] _time_event_counter;
     _time_conditions = new bool[_dimTimeEvent];
-
-
-    _time_event_counter = new int[_dimTimeEvent];
-
     memset(_time_conditions,false,(_dimTimeEvent)*sizeof(bool));
-    memset(_time_event_counter,0,(_dimTimeEvent)*sizeof(int));
   }
   if (_dimClock > 0)
   {
@@ -254,11 +261,13 @@ void SystemDefaultImplementation::initialize()
     memset(_clockCondition,false,(_dimClock)*sizeof(bool));
     if (_clockStart) delete [] _clockStart;
     _clockStart = new bool [_dimClock];
+    if (_clockSubactive) delete [] _clockSubactive;
+    _clockSubactive = new bool [_dimClock];
   }
   if(_dimRHS>0)
   {
-	   if (__daeResidual) delete [] __daeResidual;
-          __daeResidual = new double [_dimRHS];
+    if (__daeResidual) delete [] __daeResidual;
+      __daeResidual = new double [_dimRHS];
   }
   _start_time = 0.0;
   _terminal = false;
@@ -271,6 +280,24 @@ void SystemDefaultImplementation::setTime(const double& t)
   _simTime = t;
 };
 
+// Get current integration time
+double SystemDefaultImplementation::getTime()
+{
+  return _simTime;
+}
+
+/// Set status of independent variables
+void SystemDefaultImplementation::setFreeVariablesLock(bool freeVariablesLock)
+{
+  _freeVariablesLock = freeVariablesLock;
+}
+
+// Get status of independent variables
+bool SystemDefaultImplementation::getFreeVariablesLock()
+{
+  return _freeVariablesLock;
+}
+
 /// getter for variables of different types
 void SystemDefaultImplementation::getBoolean(bool* z)
 {
@@ -428,10 +455,11 @@ void SystemDefaultImplementation::setReal(const double* z)
   }
 };
 
-void SystemDefaultImplementation::setClock(const bool* z)
+void SystemDefaultImplementation::setClock(const bool* tick, const bool* subactive)
 {
-  for(int i = _dimTimeEvent - _dimClock; i < _dimTimeEvent; i++) {
-    _time_conditions[i] = z[i];
+  for (int i = 0; i < _dimClock; i++) {
+    _time_conditions[_dimTimeEvent - _dimClock + i] = tick[i];
+    _clockSubactive[i] = subactive[i];
   }
 }
 
@@ -465,7 +493,7 @@ void SystemDefaultImplementation::getRHS(double* f)
 
 void SystemDefaultImplementation::getResidual(double* f)
 {
-	 std::copy(__daeResidual, __daeResidual+_dimRHS, f);
+   std::copy(__daeResidual, __daeResidual+_dimRHS, f);
 }
 
 void  SystemDefaultImplementation::intDelay(vector<unsigned int> expr, vector<double> delay_max)
@@ -606,49 +634,176 @@ string& SystemDefaultImplementation::getStringStartValue(string& var)
   return _string_start_values.getGetStartValue(var);
 }
 
-void SystemDefaultImplementation::setRealStartValue(double& var,double val)
+void SystemDefaultImplementation::setRealStartValue(double& var, double val, bool overwriteOldValue)
 {
-  setRealStartValue(var,val,false);
+  var = val;
+  _real_start_values.setStartValue(var, val, overwriteOldValue);
 }
 
-void SystemDefaultImplementation::setRealStartValue(double& var,double val,bool overwriteOldValue)
+void SystemDefaultImplementation::setRealStartValue(BaseArray<double>& avar, double val, bool overwriteOldValue)
 {
-  var=val;
-  _real_start_values.setStartValue(var,val,overwriteOldValue);
+  double *varp = avar.getData();
+  size_t nel = avar.getNumElems();
+  for (size_t i = 0; i < nel; varp++, i++) {
+    *varp = val;
+    _real_start_values.setStartValue(*varp, val, overwriteOldValue);
+  }
 }
 
-void SystemDefaultImplementation::setBoolStartValue(bool& var,bool val)
+void SystemDefaultImplementation::setRealStartValue(BaseArray<double>& avar, const BaseArray<double>& aval, bool overwriteOldValue)
 {
-  setBoolStartValue(var,val,false);
+  double *varp = avar.getData();
+  const double *valp = aval.getData();
+  size_t nel = avar.getNumElems();
+  for (size_t i = 0; i < nel; varp++, valp++, i++) {
+    *varp = *valp;
+    _real_start_values.setStartValue(*varp, *valp, overwriteOldValue);
+  }
 }
 
-void SystemDefaultImplementation::setBoolStartValue(bool& var,bool val,bool overwriteOldValue)
+void SystemDefaultImplementation::setBoolStartValue(bool& var, bool val, bool overwriteOldValue)
 {
-  var=val;
-  _bool_start_values.setStartValue(var,val,overwriteOldValue);
+  var = val;
+  _bool_start_values.setStartValue(var, val, overwriteOldValue);
 }
 
-void SystemDefaultImplementation::setIntStartValue(int& var,int val)
+void SystemDefaultImplementation::setBoolStartValue(BaseArray<bool>& avar, bool val, bool overwriteOldValue)
 {
-  setIntStartValue(var,val,false);
+  bool *varp = avar.getData();
+  size_t nel = avar.getNumElems();
+  for (size_t i = 0; i < nel; varp++, i++) {
+    *varp = val;
+    _bool_start_values.setStartValue(*varp, val, overwriteOldValue);
+  }
 }
 
-void SystemDefaultImplementation::setIntStartValue(int& var,int val,bool overwriteOldValue)
+void SystemDefaultImplementation::setBoolStartValue(BaseArray<bool>& avar, const BaseArray<bool>& aval, bool overwriteOldValue)
 {
-  var=val;
-  _int_start_values.setStartValue(var,val,overwriteOldValue);
+  bool *varp = avar.getData();
+  const bool *valp = aval.getData();
+  size_t nel = avar.getNumElems();
+  for (size_t i = 0; i < nel; varp++, valp++, i++) {
+    *varp = *valp;
+    _bool_start_values.setStartValue(*varp, *valp, overwriteOldValue);
+  }
 }
 
-void SystemDefaultImplementation::setStringStartValue(string& var,string val)
+void SystemDefaultImplementation::setIntStartValue(int& var, int val, bool overwriteOldValue)
 {
-  setStringStartValue(var,val,false);
+  var = val;
+  _int_start_values.setStartValue(var, val, overwriteOldValue);
 }
 
-void SystemDefaultImplementation::setStringStartValue(string& var,string val,bool overwriteOldValue)
+void SystemDefaultImplementation::setIntStartValue(BaseArray<int>& avar, int val, bool overwriteOldValue)
 {
-  var=val;
-  _string_start_values.setStartValue(var,val,overwriteOldValue);
+  int *varp = avar.getData();
+  size_t nel = avar.getNumElems();
+  for (size_t i = 0; i < nel; varp++, i++) {
+    *varp = val;
+    _int_start_values.setStartValue(*varp, val, overwriteOldValue);
+  }
 }
+
+void SystemDefaultImplementation::setIntStartValue(BaseArray<int>& avar, const BaseArray<int>& aval, bool overwriteOldValue)
+{
+  int *varp = avar.getData();
+  const int *valp = aval.getData();
+  size_t nel = avar.getNumElems();
+  for (size_t i = 0; i < nel; varp++, valp++, i++) {
+    *varp = *valp;
+    _int_start_values.setStartValue(*varp, *valp, overwriteOldValue);
+  }
+}
+
+void SystemDefaultImplementation::setStringStartValue(string& var, string val, bool overwriteOldValue)
+{
+  var = val;
+  _string_start_values.setStartValue(var, val, overwriteOldValue);
+}
+
+void SystemDefaultImplementation::setStringStartValue(BaseArray<string>& avar, string val, bool overwriteOldValue)
+{
+  string *varp = avar.getData();
+  size_t nel = avar.getNumElems();
+  for (size_t i = 0; i < nel; varp++, i++) {
+    *varp = val;
+    _string_start_values.setStartValue(*varp, val, overwriteOldValue);
+  }
+}
+
+void SystemDefaultImplementation::setStringStartValue(BaseArray<string>& avar, const BaseArray<string>& aval, bool overwriteOldValue)
+{
+  string *varp = avar.getData();
+  const string *valp = aval.getData();
+  size_t nel = avar.getNumElems();
+  for (size_t i = 0; i < nel; varp++, valp++, i++) {
+    *varp = *valp;
+    _string_start_values.setStartValue(*varp, *valp, overwriteOldValue);
+  }
+}
+
+/**
+    Computes whether time event conditions are active at current time
+    @param The current time
+*/
+void SystemDefaultImplementation::computeTimeEventConditions(double currTime)
+{
+  for (int i=0; i< _dimTimeEvent; i++)
+  {
+    if (std::abs(_currTimeEvents[i] - currTime) <= 1e4*UROUND)
+    {
+      _time_conditions[i] = true;
+    }
+    else
+    {
+      _time_conditions[i] = false;
+    }
+  }
+}
+
+/**
+    Sets all time event conditions to false
+*/
+void SystemDefaultImplementation::resetTimeConditions()
+{
+  for (int i=0; i< _dimTimeEvent; i++)
+  {
+  _time_conditions[i] = false;
+  }
+}
+
+/**
+    Computes the next time events for each time event sampler
+    @param The current Time
+    @param The definition of the time event samplers (starttime, intervall)
+    @param An array of the next time events for each sampler
+    @return the closest time event
+*/
+double SystemDefaultImplementation::computeNextTimeEvents(double currTime, std::pair<double, double>* timeEventPairs)
+{
+  double closestTimeEvent = std::numeric_limits<double>::max();
+  double nextTimeEvent = 0;
+  double pastIntervalls;
+
+  for (  int timerIdx = 0; timerIdx < _dimTimeEvent ; timerIdx++)
+  {
+    //the time event samples started already
+    if(timeEventPairs[timerIdx].first <= currTime)
+    {
+      pastIntervalls = std::floor((currTime - timeEventPairs[timerIdx].first + 1e4*UROUND) / timeEventPairs[timerIdx].second);
+      _currTimeEvents[timerIdx] = timeEventPairs[timerIdx].first + (pastIntervalls) * timeEventPairs[timerIdx].second;
+      nextTimeEvent = _currTimeEvents[timerIdx] + timeEventPairs[timerIdx].second;
+    }
+    else
+    {
+      nextTimeEvent = timeEventPairs[timerIdx].first;
+      _currTimeEvents[timerIdx] = 1.0;
+    }
+    closestTimeEvent = std::min(closestTimeEvent, nextTimeEvent);
+  }
+  return closestTimeEvent;
+}
+
 /** @} */ // end of coreSystem
 
 /*
