@@ -59,6 +59,7 @@ extern "C" {
 #include <QMdiSubWindow>
 #include <QMdiArea>
 #include <QShortcut>
+#include <QRadioButton>
 
 class OMCProxy;
 class TransformationsWidget;
@@ -88,6 +89,7 @@ class LibraryTreeItem;
 class GitCommands;
 class CommitChangesDialog;
 class TraceabilityInformationURI;
+class StatusBar;
 class TraceabilityGraphViewWidget;
 class SearchWidget;
 
@@ -95,7 +97,7 @@ class MainWindow : public QMainWindow
 {
   Q_OBJECT
 public:
-  enum { MaxRecentFiles = 8 };
+  enum { MaxRecentModels = 8 };
 private:
   MainWindow(QWidget *parent = 0);
   static MainWindow *mpInstance;
@@ -137,7 +139,7 @@ public:
   GitCommands* getGitCommands() {return mpGitCommands;}
   CommitChangesDialog* getCommitChangesDialog() {return mpCommitChangesDialog;}
   TraceabilityInformationURI* getTraceabilityInformationURI() {return mpTraceabilityInformationURI;}
-  QStatusBar* getStatusBar() {return mpStatusBar;}
+  StatusBar* getStatusBar() {return mpStatusBar;}
   QProgressBar* getProgressBar() {return mpProgressBar;}
   void showProgressBar() {mpProgressBar->setVisible(true);}
   void hideProgressBar() {mpProgressBar->setVisible(false);}
@@ -160,7 +162,6 @@ public:
   QAction* getCloseAllWindowsAction() {return mpCloseAllWindowsAction;}
   QAction* getCloseAllWindowsButThisAction() {return mpCloseAllWindowsButThisAction;}
   QAction* getSimulationSetupAction() {return mpSimulationSetupAction;}
-  QAction* getOMSInstantiateModelAction() {return mpOMSInstantiateModelAction;}
   QAction* getSimulateModelAction() {return mpSimulateModelAction;}
   QAction* getSimulateWithTransformationalDebuggerAction() {return mpSimulateWithTransformationalDebuggerAction;}
   QAction* getSimulateWithAlgorithmicDebuggerAction() {return mpSimulateWithAlgorithmicDebuggerAction;}
@@ -213,7 +214,8 @@ public:
   QToolBar* getTLMSimulationToolbar() const {return mpTLMSimulationToolbar;}
   QToolBar* getOMSimulatorToobar() const {return mpOMSimulatorToobar;}
   void addRecentFile(const QString &fileName, const QString &encoding);
-  void updateRecentFileActions();
+  void updateRecentFileActionsAndList();
+  void createRecentFileActions();
   void closeEvent(QCloseEvent *event) override;
   int askForExit();
   void beforeClosingMainWindow();
@@ -226,7 +228,6 @@ public:
   void simulateWithAnimation(LibraryTreeItem *pLibraryTreeItem);
 #endif
   void simulationSetup(LibraryTreeItem *pLibraryTreeItem);
-  void instantiateOMSModel(LibraryTreeItem *pLibraryTreeItem, bool checked);
   void instantiateModel(LibraryTreeItem *pLibraryTreeItem);
   void checkModel(LibraryTreeItem *pLibraryTreeItem);
   void checkAllModels(LibraryTreeItem *pLibraryTreeItem);
@@ -298,7 +299,7 @@ private:
   QProgressBar *mpProgressBar;
   Label *mpPositionLabel;
   QTabBar *mpPerspectiveTabbar;
-  QStatusBar *mpStatusBar;
+  StatusBar *mpStatusBar;
   QTimer *mpAutoSaveTimer;
   QShortcut *mpSearchBrowserShortcut;
   // File Menu
@@ -334,7 +335,6 @@ private:
   QAction *mpExportXMLAction;
   QAction *mpExportFigaroAction;
   QAction *mpExportToOMNotebookAction;
-  QAction *mpRecentFileActions[MaxRecentFiles];
   QAction *mpClearRecentFilesAction;
   QAction *mpPrintModelAction;
   QAction *mpQuitAction;
@@ -359,7 +359,6 @@ private:
   QAction *mpCheckAllModelsAction;
   QAction *mpInstantiateModelAction;
   QAction *mpSimulationSetupAction;
-  QAction *mpOMSInstantiateModelAction;
   QAction *mpSimulateModelAction;
   QAction *mpSimulateWithTransformationalDebuggerAction;
   QAction *mpSimulateWithAlgorithmicDebuggerAction;
@@ -379,7 +378,9 @@ private:
   QAction *mpCleanWorkingDirectoryAction;
   // Tools Menu
   QAction *mpShowOMCLoggerWidgetAction;
+#ifdef Q_OS_WIN
   QAction *mpShowOpenModelicaCommandPromptAction;
+#endif
   QAction *mpShowOMCDiffWidgetAction;
   QAction *mpOpenTemporaryDirectoryAction;
   QAction *mpOpenWorkingDirectoryAction;
@@ -409,7 +410,7 @@ private:
   QAction *mpConnectModeAction;
   QAction *mpTransitionModeAction;
   // Model Switcher Toolbar Actions
-  QAction *mpModelSwitcherActions[MaxRecentFiles];
+  QAction *mpModelSwitcherActions[MaxRecentModels];
   // Plot Toolbar Actions
   QAction *mpReSimulateModelAction;
   QAction *mpReSimulateSetupAction;
@@ -500,7 +501,6 @@ public slots:
   void checkAllModels();
   void instantiateModel();
   void openSimulationDialog();
-  void instantiateOMSModel(bool checked);
   void simulateModel();
   void simulateModelWithTransformationalDebugger();
   void simulateModelWithAlgorithmicDebugger();
@@ -512,7 +512,9 @@ public slots:
   void exportReadonlyPackage();
   void exportModelXML();
   void exportModelFigaro();
+#ifdef Q_OS_WIN
   void showOpenModelicaCommandPrompt();
+#endif
   void runOMSensPlugin();
   void exportModelToOMNotebook();
   void importModelfromOMNotebook();
@@ -587,4 +589,21 @@ private slots:
   void readOMContributors(QNetworkReply *pNetworkReply);
 };
 
+class MSLVersionDialog : public QDialog
+{
+  Q_OBJECT
+public:
+  MSLVersionDialog(QWidget *parent = 0);
+private:
+  QRadioButton *mpMSL3RadioButton;
+  QRadioButton *mpMSL4RadioButton;
+  QRadioButton *mpNoMSLRadioButton;
+private slots:
+  void setMSLVersion();
+
+  // QDialog interface
+public slots:
+  virtual void reject() override;
+};
+
 #endif // MAINWINDOW_H
