@@ -413,12 +413,12 @@ QString Helper::startTime;
 QString Helper::stopTime;
 QString Helper::status;
 QString Helper::speed;
-QString Helper::instantiateOMSModelTip;
 QString Helper::terminateInstantiation;
 QString Helper::terminateInstantiationTip;
 QString Helper::archivedSimulations;
 QString Helper::systemSimulationInformation;
 QString Helper::translationFlags;
+QString Helper::send;
 
 void Helper::initHelperVariables()
 {
@@ -710,12 +710,12 @@ void Helper::initHelperVariables()
   Helper::stopTime = tr("Stop Time");
   Helper::status = tr("Status");
   Helper::speed = tr("Speed:");
-  Helper::instantiateOMSModelTip = tr("Instantiates the current SSP model");
   Helper::terminateInstantiation = tr("Terminate Instantiation");
   Helper::terminateInstantiationTip = tr("Terminates the model instantiation");
   Helper::archivedSimulations = tr("Archived Simulations");
   Helper::systemSimulationInformation = tr("System Simulation Information");
   Helper::translationFlags = tr("Translation Flags");
+  Helper::send = tr("Send");
 }
 
 QString GUIMessages::getMessage(int type)
