@@ -75,14 +75,14 @@ oms::Component* oms::ComponentTable::NewComponent(const oms::ComRef& cref, oms::
   filesystem::path relPath = parentSystem->copyResources() ? (filesystem::path("resources") / (parentSystem->getUniqueID() + "_" + std::string(cref) + extension)) : filesystem::path(path);
   filesystem::path absPath = temp_root / relPath;
 
-  ComponentTable* component = new ComponentTable(cref, parentSystem, relPath.string());
+  ComponentTable* component = new ComponentTable(cref, parentSystem, relPath.generic_string());
 
   // Copy the resource to the temp directory of the model? We don't want have
-  // do copy resources if importing an SSP or snapshot.
+  // to copy resources if importing an SSP file or snapshot.
   if (parentSystem->copyResources())
     oms_copy_file(filesystem::path(path), absPath);
 
-  component->resultReader = ResultReader::newReader(path.c_str());
+  component->resultReader = ResultReader::newReader(absPath.string().c_str());
   if (!component->resultReader)
   {
     logError("Could not load lookup table: " + path);
@@ -103,7 +103,7 @@ oms::Component* oms::ComponentTable::NewComponent(const oms::ComRef& cref, oms::
   return component;
 }
 
-oms::Component* oms::ComponentTable::NewComponent(const pugi::xml_node& node, oms::System* parentSystem)
+oms::Component* oms::ComponentTable::NewComponent(const pugi::xml_node& node, oms::System* parentSystem, const std::string& sspVersion)
 {
   ComRef cref = ComRef(node.attribute("name").as_string());
   std::string type = node.attribute("type").as_string();
@@ -131,16 +131,16 @@ oms::Component* oms::ComponentTable::NewComponent(const pugi::xml_node& node, om
   for(pugi::xml_node_iterator it = node.begin(); it != node.end(); ++it)
   {
     std::string name = it->name();
-    if(name == oms::ssd::ssd_connectors)
+    if(name == oms::ssp::Draft20180219::ssd::connectors)
     {
       // import connectors
       for(pugi::xml_node_iterator itConnectors = (*it).begin(); itConnectors != (*it).end(); ++itConnectors)
       {
-        component->connectors.push_back(oms::Connector::NewConnector(*itConnectors));
+        component->connectors.push_back(oms::Connector::NewConnector(*itConnectors, sspVersion));
         component->exportSeries[component->connectors.back()->getName()] = true;
       }
     }
-    else if(name == oms::ssd::ssd_element_geometry)
+    else if(name == oms::ssp::Draft20180219::ssd::element_geometry)
     {
       oms::ssd::ElementGeometry geometry;
       geometry.importFromSSD(*it);
@@ -160,12 +160,12 @@ oms::Component* oms::ComponentTable::NewComponent(const pugi::xml_node& node, om
   return component;
 }
 
-oms_status_enu_t oms::ComponentTable::exportToSSD(pugi::xml_node& node) const
+oms_status_enu_t oms::ComponentTable::exportToSSD(pugi::xml_node& node, pugi::xml_node& ssvNode) const
 {
   node.append_attribute("name") = this->getCref().c_str();
   node.append_attribute("type") = "application/table";
   node.append_attribute("source") = getPath().c_str();
-  pugi::xml_node node_connectors = node.append_child(oms::ssd::ssd_connectors);
+  pugi::xml_node node_connectors = node.append_child(oms::ssp::Draft20180219::ssd::connectors);
 
   if (element.getGeometry())
     element.getGeometry()->exportToSSD(node);
@@ -216,6 +216,68 @@ oms_status_enu_t oms::ComponentTable::getReal(const oms::ComRef& cref, double& v
   return logError("out of range (cref=" + std::string(cref) + ", time=" + std::to_string(time) + ")");
 }
 
+oms_status_enu_t oms::ComponentTable::getInteger(const oms::ComRef& cref, int& value)
+{
+  if (!resultReader)
+    logError("the table isn't initialized properly");
+
+  if (series.find(cref) == series.end())
+    series[cref] = resultReader->getSeries(cref.c_str());
+
+  if (series[cref]->length < 1)
+    return logError("empty table");
+  else if (series[cref]->time[0] > time)
+    return logError("out of range (cref=" + std::string(cref) + ", time=" + std::to_string(time) + " cannot be less than first time point in table " + std::to_string(series[cref]->time[0]) + ")");
+
+  for (int i=0; i<series[cref]->length; ++i)
+  {
+    if (time == series[cref]->time[i])
+    {
+      value = series[cref]->value[i];
+      return oms_status_ok;
+    }
+    else if (i > 0 && time < series[cref]->time[i])
+    {
+      value = series[cref]->value[i-1];
+      return oms_status_ok;
+    }
+  }
+
+  value = 0;
+  return logError("out of range (cref=" + std::string(cref) + ", time=" + std::to_string(time) + ")");
+}
+
+oms_status_enu_t oms::ComponentTable::getBoolean(const oms::ComRef& cref, bool& value)
+{
+  if (!resultReader)
+    logError("the table isn't initialized properly");
+
+  if (series.find(cref) == series.end())
+    series[cref] = resultReader->getSeries(cref.c_str());
+
+  if (series[cref]->length < 1)
+    return logError("empty table");
+  else if (series[cref]->time[0] > time)
+    return logError("out of range (cref=" + std::string(cref) + ", time=" + std::to_string(time) + " cannot be less than first time point in table " + std::to_string(series[cref]->time[0]) + ")");
+
+  for (int i=0; i<series[cref]->length; ++i)
+  {
+    if (time == series[cref]->time[i])
+    {
+      value = series[cref]->value[i];
+      return oms_status_ok;
+    }
+    else if (i > 0 && time < series[cref]->time[i])
+    {
+      value = series[cref]->value[i-1];
+      return oms_status_ok;
+    }
+  }
+
+  value = 0;
+  return logError("out of range (cref=" + std::string(cref) + ", time=" + std::to_string(time) + ")");
+}
+
 oms_status_enu_t oms::ComponentTable::getRealOutputDerivative(const ComRef& cref, SignalDerivative& value)
 {
   if (!resultReader)
